==> pde-2.21.0.tgz: package/lib/hooks/useFeature.js <==
import { useContext } from 'react';
import PdeContext from '../contexts/PdeContext.js';
import { getPlatformStrategy } from './common/platformStrategies.js';
var VARIATION_NAME_ON = 'On State';
var VARIATION_NAME_OFF = 'Off State';

/**
 * track feature flag's own Experiment Viewed event
 * @param {object} param
 * @param {boolean} param.isActive
 * @param {function} param.trackExperimentViewed
 * @param {string} param.featureKey
 */
var trackFeatureFlagViewed = function trackFeatureFlagViewed(_ref) {
  var isActive = _ref.isActive,
    trackExperimentViewed = _ref.trackExperimentViewed,
    featureKey = _ref.featureKey;
  var variationName = isActive ? VARIATION_NAME_ON : VARIATION_NAME_OFF;
  trackExperimentViewed({
    experimentName: featureKey,
    variationName: variationName
  });
};

/**
 * track every linked experiment's Experiment Viewed event
 * @param {object} param
 * @param {linkedExperiments} string[] feature tests using the current feature flag
 * @param {function} trackExperimentViewed
 * @param {object} attributes user attributes to take into account for its segmentation
 * @param {object} pde
 * @param {string} adapterId
 */
var trackLinkedExperimentsViewed = function trackLinkedExperimentsViewed(_ref2) {
  var linkedExperiments = _ref2.linkedExperiments,
    trackExperimentViewed = _ref2.trackExperimentViewed,
    attributes = _ref2.attributes,
    pde = _ref2.pde,
    adapterId = _ref2.adapterId;
  if (!linkedExperiments) return;
  linkedExperiments.forEach(function (experimentName) {
    var variationName = pde.getVariation({
      name: experimentName,
      attributes: attributes,
      adapterId: adapterId
    });
    trackExperimentViewed({
      variationName: variationName,
      experimentName: experimentName
    });
  });
};

/**
 * Hook to use a feature toggle
 * @param {string} featureKey
 * @param {object} attributes
 * @param {string} [queryString] test purposes only
 * @param {string} adapterId
 * @return {{isActive: boolean}}
 */
export default function useFeature(featureKey, attributes, queryString, adapterId) {
  var _useContext = useContext(PdeContext),
    pde = _useContext.pde;
  if (pde === null) throw new Error('[useFeature] sui-pde provider is required to work');
  var strategy = getPlatformStrategy();
  var forcedValue = strategy.getForcedValue({
    key: featureKey,
    queryString: queryString
  });
  try {
    if (forcedValue) {
      return {
        isActive: forcedValue === 'on',
        linkedExperiments: []
      };
    }
    var _pde$isFeatureEnabled = pde.isFeatureEnabled({
        featureKey: featureKey,
        attributes: attributes,
        adapterId: adapterId
      }),
      isActive = _pde$isFeatureEnabled.isActive,
      linkedExperiments = _pde$isFeatureEnabled.linkedExperiments;
    var variables = pde.getAllFeatureVariables({
      featureKey: featureKey,
      attributes: attributes,
      adapterId: adapterId
    });
    trackFeatureFlagViewed({
      isActive: isActive,
      trackExperimentViewed: strategy.trackExperiment,
      featureKey: featureKey
    });
    trackLinkedExperimentsViewed({
      linkedExperiments: linkedExperiments,
      trackExperimentViewed: strategy.trackExperiment,
      pde: pde,
      attributes: attributes,
      adapterId: adapterId
    });
    return {
      isActive: isActive,
      variables: variables
    };
  } catch (error) {
    // eslint-disable-next-line no-console
    console.error(error);
    return {
      isActive: false,
      variables: {}
    };
  }
}

==> pde-2.32.0.tgz: package/lib/hooks/useFeature.js <==
import { useContext } from 'react';
import PdeContext from '../contexts/PdeContext.js';
import { getPlatformStrategy } from './common/platformStrategies.js';
var VARIATION_NAME_ON = 'On State';
var VARIATION_NAME_OFF = 'Off State';

/**
 * track feature flag's own Experiment Viewed event
 * @param {object} param
 * @param {boolean} param.isActive
 * @param {function} param.trackExperimentViewed
 * @param {string} param.featureKey
 */
var trackFeatureFlagViewed = function trackFeatureFlagViewed(_ref) {
  var isActive = _ref.isActive,
    trackExperimentViewed = _ref.trackExperimentViewed,
    featureKey = _ref.featureKey;
  var variationName = isActive ? VARIATION_NAME_ON : VARIATION_NAME_OFF;
  trackExperimentViewed({
    experimentName: featureKey,
    variationName: variationName
  });
};

/**
 * track every linked experiment's Experiment Viewed event
 * @param {object} param
 * @param {linkedExperiments} string[] feature tests using the current feature flag
 * @param {function} trackExperimentViewed
 * @param {object} attributes user attributes to take into account for its segmentation
 * @param {object} pde
 * @param {string} adapterId
 */
var trackLinkedExperimentsViewed = function trackLinkedExperimentsViewed(_ref2) {
  var linkedExperiments = _ref2.linkedExperiments,
    trackExperimentViewed = _ref2.trackExperimentViewed,
    attributes = _ref2.attributes,
    pde = _ref2.pde,
    adapterId = _ref2.adapterId;
  if (!linkedExperiments) return;
  linkedExperiments.forEach(function (experimentName) {
    var variationName = pde.getVariation({
      name: experimentName,
      attributes: attributes,
      adapterId: adapterId
    });
    trackExperimentViewed({
      variationName: variationName,
      experimentName: experimentName
    });
  });
};

/**
 * Hook to use a feature toggle
 * @param {string} featureKey
 * @param {object} attributes
 * @param {string} [queryString] test purposes only
 * @param {string} adapterId
 * @return {{isActive: boolean}}
 */
export default function useFeature(featureKey, attributes, queryString, adapterId, shouldTrackExperimentViewed) {
  var _useContext = useContext(PdeContext),
    pde = _useContext.pde;
  if (pde === null) throw new Error('[useFeature] sui-pde provider is required to work');
  var strategy = getPlatformStrategy();
  var forcedValue = strategy.getForcedValue({
    key: featureKey,
    queryString: queryString
  });
  try {
    if (forcedValue) {
      return {
        isActive: forcedValue === 'on',
        linkedExperiments: []
      };
    }
    var _pde$isFeatureEnabled = pde.isFeatureEnabled({
        featureKey: featureKey,
        attributes: attributes,
        adapterId: adapterId
      }),
      isActive = _pde$isFeatureEnabled.isActive,
      linkedExperiments = _pde$isFeatureEnabled.linkedExperiments;
    var variables = pde.getAllFeatureVariables({
      featureKey: featureKey,
      attributes: attributes,
      adapterId: adapterId
    });
    if (shouldTrackExperimentViewed) {
      trackFeatureFlagViewed({
        isActive: isActive,
        trackExperimentViewed: strategy.trackExperiment,
        featureKey: featureKey
      });
      trackLinkedExperimentsViewed({
        linkedExperiments: linkedExperiments,
        trackExperimentViewed: strategy.trackExperiment,
        pde: pde,
        attributes: attributes,
        adapterId: adapterId
      });
    }
    return {
      isActive: isActive,
      variables: variables
    };
  } catch (error) {
    // eslint-disable-next-line no-console
    console.error(error);
    return {
      isActive: false,
      variables: {}
    };
  }
}
